@@ -14,6 +14,5 @@
 
 """A client library for Google's SOAP Ads APIs."""
 
-from adwords import AdWordsClient
-from dfa import DfaClient
-from dfp import DfpClient
+from .ad_manager import AdManagerClient
+from .adwords import AdWordsClient
